==> slurm_rest_client-0.1.3-py3-none-any.whl: slurm_rest_client/models/v0040_reservation_info_purge_completed.py <==
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.v0040_reservation_info_purge_completed_time import V0040ReservationInfoPurgeCompletedTime


T = TypeVar("T", bound="V0040ReservationInfoPurgeCompleted")


@_attrs_define
class V0040ReservationInfoPurgeCompleted:
    """
    Attributes:
        time (Union[Unset, V0040ReservationInfoPurgeCompletedTime]):
    """

    time: Union[Unset, "V0040ReservationInfoPurgeCompletedTime"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        time: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.time, Unset):
            time = self.time.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if time is not UNSET:
            field_dict["time"] = time

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.v0040_reservation_info_purge_completed_time import V0040ReservationInfoPurgeCompletedTime

        d = dict(src_dict)
        _time = d.pop("time", UNSET)
        time: Union[Unset, V0040ReservationInfoPurgeCompletedTime]
        if isinstance(_time, Unset):
            time = UNSET
        else:
            time = V0040ReservationInfoPurgeCompletedTime.from_dict(_time)

        v0040_reservation_info_purge_completed = cls(
            time=time,
        )

        v0040_reservation_info_purge_completed.additional_properties = d
        return v0040_reservation_info_purge_completed

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> slurm_rest_client-0.1.4-py3-none-any.whl: slurm_rest_client/models/v0040_reservation_info_purge_completed.py <==
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="V0040ReservationInfoPurgeCompleted")


@_attrs_define
class V0040ReservationInfoPurgeCompleted:
    """
    Attributes:
        time (Union[Unset, int]):
    """

    time: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        time = self.time

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if time is not UNSET:
            field_dict["time"] = time

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        time = d.pop("time", UNSET)

        v0040_reservation_info_purge_completed = cls(
            time=time,
        )

        v0040_reservation_info_purge_completed.additional_properties = d
        return v0040_reservation_info_purge_completed

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
